@@ -30,7 +30,7 @@ class LatentCategorical(Model):
 
     def model(self,i = 1,  *args, **kwargs):
 
-        Temperature = self._params['Temperature'] / np.log2(i)
+        Temperature = self._params['Temperature'] / np.log2(i + 0.1)
 
         ### CHeck the existence of the single modality and get its dimensions
         if 'data_rna' in self._data:
@@ -131,8 +131,6 @@ class LatentCategorical(Model):
 
                     segment_fact_marg_rna = segment_fact_cat * cc_argmax
 
-                    #print(segment_fact_marg_rna[:, 5, :])
-
                     segment_fact_marg_rna = torch.sum(segment_fact_marg_rna, dim=-1)
 
                     if self._params["likelihood_rna"] == "NB":
@@ -172,6 +170,7 @@ class LatentCategorical(Model):
                     segment_fact_marg_atac = torch.sum(segment_fact_marg_atac, dim=-1)
 
 
+
                     if self._params["likelihood_atac"] == "NB":
                         lk_atac = lks.NB_likelihood(self, segment_fact_marg_atac, weights_atac, sizes_atac, "atac")
                     elif self._params["likelihood_atac"] == "P":
@@ -180,7 +179,8 @@ class LatentCategorical(Model):
                         lk_atac = lks.gaussian_likelihood(self, segment_fact_marg_atac, weights_atac, norm_sd_atac, "atac")
 
         if self._params["latent_type"] == "D":
-            pyro.factor("lk", self._params['lambda'] * lk_rna + (1-self._params['lambda']) * lk_atac - torch.tensor(N * M / self._params['hidden_dim'], dtype = torch.float) * entropy_CNV(cc))
+            pyro.factor("lk", self._params['lambda'] * lk_rna + (1-self._params['lambda']) * lk_atac -
+                        torch.tensor((self._params['lambda'] * N) * ((1 - self._params['lambda']) * M) / self._params['hidden_dim'], dtype = torch.float) * entropy_CNV(cc))
         else:
             pyro.factor("lk", self._params['lambda'] * lk_rna + (1-self._params['lambda']) * lk_atac)
 
@@ -264,9 +264,8 @@ class LatentCategorical(Model):
 
     def likelihood(self, inf_params, mod = "rna",sum = False):
 
-        Temperature = self._params['Temperature'] / 1000
         I, N = self._data['data_{}'.format(mod)].shape
-        cat_vector = torch.tensor(np.arange(1,self._params['hidden_dim'] + 1), dtype=torch.float)
+        cat_vector = torch.tensor(np.arange(1,self._params['hidden_dim'] + 1).copy(), dtype=torch.float)
 
 
         if self._params["likelihood_{}".format(mod)] in ["G", "N"]:
@@ -277,21 +276,26 @@ class LatentCategorical(Model):
         segment_fact = torch.matmul(segment_fact.reshape([I, 1]),
                                     cat_vector.reshape([1, self._params['hidden_dim']]))
 
-        gumble = tdist.Gumbel(0, 1).sample(inf_params["CNV_probabilities"].shape)
 
-        cc_argmax = ((torch.log(inf_params["CNV_probabilities"]) + gumble) / Temperature).softmax(-1)
+        cc_ones = torch.argmax(inf_params["CNV_probabilities"], dim=-1)
 
 
 
 
+        cc_argmax = torch.zeros_like(inf_params["CNV_probabilities"])
+
+
+        for i in range(cc_argmax.shape[0]):
+            for j in range(cc_argmax.shape[1]):
+                cc_argmax[i,j,cc_ones[i,j]] = 1
+
+
 
         segment_fact_marg = segment_fact * cc_argmax
 
 
-
         segment_fact_marg = torch.sum(segment_fact_marg, dim=-1)
 
-        #print(segment_fact_marg[:, :])
 
 
         if self._params["likelihood_{}".format(mod)] == "NB":
@@ -334,6 +338,7 @@ class LatentCategorical(Model):
         ### CLUSTER ASSIGNMENTS FOR RNA ###
 
         if 'data_rna' in self._data:
+            I, N = self._data['data_rna'].shape
             lk = self.likelihood(inf_params, "rna")
             # p(z_i| D, X ) = lk(z_i) * p(z_i | X) / sum_z_i(lk(z_i) * p(z_i | X))
             # log(p(z_i| D, X )) = log(lk(z_i)) + log(p(z_i | X)) - log_sum_exp(log(lk(z_i)) + log(p(z_i | X)))
@@ -350,11 +355,13 @@ class LatentCategorical(Model):
         ### CLUSTER ASSIGNMENTS FOR DNA ###
 
         if 'data_atac' in self._data:
+            I, M = self._data['data_atac'].shape
             lk = self.likelihood(inf_params, "atac")
             lk = torch.sum(lk, dim=1) + torch.log(inf_params["mixture_weights_atac"]).reshape([self._params['K'], 1])
-            print(lk)
+
             summed_lk = log_sum_exp(lk)
             ret_atac = lk - summed_lk
+
             ret_atac = torch.exp(ret_atac)
             res["assignment_probs_atac"] = ret_atac
             res["assignment_atac"] = torch.argmax(ret_atac, axis = 0)
